@@ -169,6 +169,22 @@ blockForest <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NUL
       response <- data[, c(dependent.variable.name, status.variable.name)]
     }
     data.selected <- data
+    
+    # Dependent variable has to be first in blockForest
+    if (status.variable.name == "none" || is.null(status.variable.name)) {
+      if (colnames(data.selected)[1] != dependent.variable.name) {
+        dependent.varID <- which(colnames(data.selected) == dependent.variable.name)
+        data.selected <- cbind(data.selected[, dependent.varID], data.selected[, -dependent.varID, drop = FALSE])
+        colnames(data.selected)[1] <- dependent.variable.name
+      }
+    } else {
+      if ((colnames(data.selected)[1] != dependent.variable.name) || (colnames(data.selected)[2] != status.variable.name)) {
+        dependent.varID <- which(colnames(data.selected) == dependent.variable.name)
+        status.varID <- which(colnames(data.selected) == status.variable.name)
+        data.selected <- cbind(data.selected[, c(dependent.varID, status.varID)], data.selected[, c(-dependent.varID, -status.varID), drop = FALSE])
+        colnames(data.selected)[c(1,2)] <- c(dependent.variable.name, status.variable.name)
+      }
+    }
   } else {
     formula <- formula(formula)
     if (class(formula) != "formula") {
@@ -590,9 +606,6 @@ blockForest <- function(formula = NULL, data = NULL, num.trees = 500, mtry = NUL
     } else {
       stop("Error: Unknown value for 'block.method'.") 
     }
-    if (is.null(formula)) {
-      stop("Error: Block forests only allowed with the formula interface.")
-    }
     if (class(blocks) != "list" || !all(sapply(blocks, is.numeric))) {
       stop("Error: The 'blocks' argument is no list of numeric vectors.")
     }
