@@ -758,7 +758,7 @@ void TreeClassification::bootstrapClassWise() {
   for (size_t i = 0; i < sample_fraction->size(); ++i) {
     // Draw samples of class with replacement as inbag and mark as not OOB
     size_t num_samples_class = (*sampleIDs_per_class)[i].size();
-    size_t num_samples_inbag_class = num_samples * (*sample_fraction)[i];
+    size_t num_samples_inbag_class = round(num_samples * (*sample_fraction)[i]);
     std::uniform_int_distribution<size_t> unif_dist(0, num_samples_class - 1);
     for (size_t s = 0; s < num_samples_inbag_class; ++s) {
       size_t draw = (*sampleIDs_per_class)[i][unif_dist(random_number_generator)];
@@ -793,7 +793,7 @@ void TreeClassification::bootstrapWithoutReplacementClassWise() {
 // Draw samples for each class
   for (size_t i = 0; i < sample_fraction->size(); ++i) {
     size_t num_samples_class = (*sampleIDs_per_class)[i].size();
-    size_t num_samples_inbag_class = num_samples * (*sample_fraction)[i];
+    size_t num_samples_inbag_class = round(num_samples * (*sample_fraction)[i]);
 
     shuffleAndSplitAppend(sampleIDs[0], oob_sampleIDs, num_samples_class, num_samples_inbag_class,
         (*sampleIDs_per_class)[i], random_number_generator);
